A sf object containing shapefiles of buffers around remote MPAs in Mexico.
The buffer equals the area inside each MPA polygon and was created to assess differences in fishing
activity inside or outside each of the remote MPAs.
mpas_buffersA simple feature collection with 5 features and 2 fields
Name of the MPAs to which the buffer correspond
empty
column containing geometry details
...