A data.frame object containing catch data per each vessel from 2008 to 2021.
Vessels are only from the Pacific and are only Tuna, Sharks, and Marlin catches.
The dataset was created by wrangling and filtering the raw data (available under request to the authors).
pacific_landingsA data.frame with 23,231 rows and 5 columns
Date of the catch report
Vessel RNP unique ID code
Official name of the vessel
Final weight of the catch in tons
Days at sea that were declared at port
...