# Download single year
# in Ubuntu it draws a certificate error when downloading, testing in windows and MacOS
# does not draw that error and you can use default certificate checking.
# \donttest{
vms_download(2019, destination.folder = tempdir(), check.url.certificate = FALSE)
# }
Run the code above in your browser using DataLab